==> haskell-libyaml-0.1.4-131-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-IBUXcupBhLb47Zivz9SbG5
key:                    libyaml-0.1.4-IBUXcupBhLb47Zivz9SbG5
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    c5ebdd3750de478152c8ddf61c5bf04c
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-IBUXcupBhLb47Zivz9SbG5
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.4-150-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-D37F1twDGDP1QzpNH4L34b
key:                    libyaml-0.1.4-D37F1twDGDP1QzpNH4L34b
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    495d9d81c3ce7af185fc0519be776d7d
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-D37F1twDGDP1QzpNH4L34b
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
